==> haskell-concurrent-supply-0.1.8-210.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-concurrent-supply.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 concurrent-supply
version:              0.1.8
visibility:           public
id:                   concurrent-supply-0.1.8-DTnV9ni8P4BKkvW7JPxjHb
key:                  concurrent-supply-0.1.8-DTnV9ni8P4BKkvW7JPxjHb
license:              BSD-3-Clause
copyright:            Copyright (C) 2011 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/concurrent-supply/
synopsis:             A fast concurrent unique identifier supply with a pure API
description:
    A fast supply of concurrent unique identifiers suitable for use
    within a single process. Once the initial '\''Supply'\'' has been initialized,
    the remainder of the API is pure. See "Control.Concurrent.Supply" for
    details.

category:             Concurrency, Parallelism
abi:                  5c56ec94ecf45ffd9000bc3a362876ac
exposed:              True
exposed-modules:      Control.Concurrent.Supply
import-dirs:          /usr/lib/ghc-9.2.8/site-local/concurrent-supply-0.1.8
library-dirs:         /usr/lib/ghc-9.2.8/site-local/concurrent-supply-0.1.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-concurrent-supply
hs-libraries:         HSconcurrent-supply-0.1.8-DTnV9ni8P4BKkvW7JPxjHb
depends:
    base-4.16.4.0 ghc-prim-0.8.0
    hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r

haddock-interfaces:
    /usr/share/doc/haskell-concurrent-supply/html/concurrent-supply.haddock

haddock-html:         /usr/share/doc/haskell-concurrent-supply/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-concurrent-supply-0.1.8-238.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-concurrent-supply.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 concurrent-supply
version:              0.1.8
visibility:           public
id:                   concurrent-supply-0.1.8-AvkBpA29JSXLx7ZA2MiyOE
key:                  concurrent-supply-0.1.8-AvkBpA29JSXLx7ZA2MiyOE
license:              BSD-3-Clause
copyright:            Copyright (C) 2011 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/concurrent-supply/
synopsis:             A fast concurrent unique identifier supply with a pure API
description:
    A fast supply of concurrent unique identifiers suitable for use
    within a single process. Once the initial '\''Supply'\'' has been initialized,
    the remainder of the API is pure. See "Control.Concurrent.Supply" for
    details.

category:             Concurrency, Parallelism
abi:                  c6c39e97e37dffc2c4d74e3881b032d0
exposed:              True
exposed-modules:      Control.Concurrent.Supply
import-dirs:          /usr/lib/ghc-9.4.8/site-local/concurrent-supply-0.1.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/concurrent-supply-0.1.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/concurrent-supply-0.1.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-concurrent-supply
hs-libraries:         HSconcurrent-supply-0.1.8-AvkBpA29JSXLx7ZA2MiyOE
depends:
    base-4.17.2.1 ghc-prim-0.9.1
    hashable-1.4.4.0-AT2Ub72SgpTFIbLYNtgVpj

haddock-interfaces:
    /usr/share/doc/haskell-concurrent-supply/html/concurrent-supply.haddock

haddock-html:         /usr/share/doc/haskell-concurrent-supply/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
